==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/shopping/search_results.php <==
<?

$t = new Template();
$t->set_file(array("page" => "templates/search_results.ihtml"));
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
$t->set_var("wwwroot", $CFG->wwwroot);
$t->set_var("productswww", $CFG->productswww);
$t->set_var("ME", $ME);
$t->set_var("id", $id);

$t->set_block("page", "num_pages", "num_pages_blck");
$t->set_var("num_pages_blck", "");
$summary_report = $t->get_var("Search_Results") . ": " . $SESSION["numr"];
$t->set_block("page", "pages_links_top", "pages_links_top_blck");
$t->set_var("pages_links_top_blck", "");
$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
$t->set_var("pages_links_bottom_blck", "");
if ($num_pages > 1) {
	$summary_report .= " " . $t->get_var("on") . " " . $num_pages . " " . $t->get_var("pages");
	require("pages_links.php");
	$t->set_var("pages_links", $pages_links);
	$t->parse("pages_links_top_blck", "pages_links_top", true);
	$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
}
$t->set_var("summary_report", $summary_report);
$t->set_block("page", "products", "products_blck");
$t->set_var("products_blck", "");
// Let us define blocks nested inside a product_row...
// We indent the code to highlight the blocks' hierarchical nesting...
$t->set_block("products", "product_row", "product_rows");
	$t->set_block("product_row", "adminprod", "adminprod_blck");
		$t->set_block("adminprod", "adminprodimage", "adminprodimage_blck");
		$t->set_block("adminprod", "special_flag", "special_flag_blck");
	$t->set_block("product_row", "notadminprod", "notadminprod_blck");
		$t->set_block("notadminprod", "notadminprodimage", "notadminprodimage_blck");
	$t->set_block("product_row", "brand_used", "brand_used_blck");
	$t->set_block("product_row", "iva_used", "iva_used_blck");
	$t->set_block("product_row", "discount_block", "discount_block_blck");
		$t->set_block("discount_block", "discqty_block", "discqty_block_blck");
	$t->set_block("product_row", "weight_used", "weight_used_blck");
// ... end of the blocks :)
$t->set_var("product_rows", "");	// Now let us reset the product rows container...
for ($i=$first; $i<=$last; $i++) {
// Now let us reset the blocks contents...
// We indent the code to highlight the blocks' hierarchical nesting...
	$t->set_var("adminprod_blck", "");
		$t->set_var("adminprodimage_blck", "");
		$t->set_var("special_flag_blck", "");
	$t->set_var("notadminprod_blck", "");
		$t->set_var("notadminprodimage_blck", "");
	$t->set_var("brand_used_blck", "");
	$t->set_var("iva_used_blck", "");
	$t->set_var("discount_block_blck", "");
		$t->set_var("discqty_block_blck", "");
	$t->set_var("weight_used_blck", "");
// ... now we have reset all nested blocks :)
	$t->set_var(array(
		"product_id"	=> $SESSION["searchres"][$i]["id"],
		"pname"		=> ov($SESSION["searchres"][$i]["name"]),
		"price"		=> $SESSION["searchres"][$i]["price"],
		"fprice"	=> formatted_price($SESSION["searchres"][$i]["price"]),
		"description"	=> ovwbr($SESSION["searchres"][$i]["description"])
	));
	if (has_priv("admin")) {
		if (file_exists($CFG->productsdir.string_cleanup($prod->id).".thumb.jpg")) {
			$t->set_var(array(
				"imagefilename"	=> string_cleanup($SESSION["searchres"][$i]["id"]),
				"thumbwidth"	=> $SESSION["searchres"][$i]["thumbwidth"],
				"thumbheight"	=> $SESSION["searchres"][$i]["thumbheight"]
			));
			$t->parse("adminprodimage_blck", "adminprodimage", true);
		}
		$t->set_var("p_special_level", $SESSION["searchres"][$i]["special_level"]);
		if ($prod->special_flag)
			$t->parse("special_flag_blck", "special_flag", true);
		$t->parse("adminprod_blck", "adminprod", true);
	} else {
		if (file_exists($CFG->productsdir.string_cleanup($prod->id).".thumb.jpg")) {
			$t->set_var(array(
				"imagefilename"	=> string_cleanup($SESSION["searchres"][$i]["id"]),
				"thumbwidth"	=> $SESSION["searchres"][$i]["thumbwidth"],
				"thumbheight"	=> $SESSION["searchres"][$i]["thumbheight"]
			));
			$t->parse("notadminprodimage_blck", "notadminprodimage", true);
		}
		$t->parse("notadminprod_blck", "notadminprod", true);
	}
	if ($SESSION["brand_used"] && $prod->bname != "") {
		$t->set_var("bname", ov($SESSION["searchres"][$i]["bname"]));
		$t->parse("brand_used_blck", "brand_used", true);
	}
	if ($SESSION["iva_used"]) {
		$t->set_var("iva", $SESSION["searchres"][$i]["iva"]);
		$t->parse("iva_used_blck", "iva_used", true);
	}
	if ($prod->discount > 0) {
		$t->set_var("discount", $SESSION["searchres"][$i]["discount"]);
		if ($prod->discqty > 1) {
			$t->set_var("discqty", $SESSION["searchres"][$i]["discqty"]);
			$t->parse("discqty_block_blck", "discqty_block", true);
		}
		$t->parse("discount_block_blck", "discount_block", true);
	}
	if ($SESSION["weight_used"]) {
		$t->set_var(array(
			"weight"	=> $SESSION["searchres"][$i]["weight"],
			"fweight"	=> formatted_weight($SESSION["searchres"][$i]["weight"])
		));
		$t->parse("weight_used_blck", "weight_used", true);
	}
	$t->parse("product_rows", "product_row", true);
}
$t->parse("products_blck", "products", true);

$t->pparse("out", "page");
//include("templates/search_results.ihtml");

?>

==> pgmarket-1.5.1.tar.gz: pgmarket-1.5.1/shopping/search_results.php <==
<?

$t = new Template();
$t->set_file(array("page" => "templates/search_results.ihtml"));
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
$t->set_var("wwwroot", $CFG->wwwroot);
$t->set_var("productswww", $CFG->productswww);
$t->set_var("ME", $ME);
$t->set_var("id", $id);

$t->set_block("page", "num_pages", "num_pages_blck");
$t->set_var("num_pages_blck", "");
$summary_report = $t->get_var("Search_Results") . ": " . $SESSION["numr"];
$t->set_block("page", "pages_links_top", "pages_links_top_blck");
$t->set_var("pages_links_top_blck", "");
$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
$t->set_var("pages_links_bottom_blck", "");
if ($num_pages > 1) {
	$summary_report .= " " . $t->get_var("on") . " " . $num_pages . " " . $t->get_var("pages");
	require("pages_links.php");
	$t->set_var("pages_links", $pages_links);
	$t->parse("pages_links_top_blck", "pages_links_top", true);
	$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
}
$t->set_var("summary_report", $summary_report);
$t->set_block("page", "products", "products_blck");
$t->set_var("products_blck", "");
// Let us define blocks nested inside a product_row...
// We indent the code to highlight the blocks' hierarchical nesting...
$t->set_block("products", "product_row", "product_rows");
	$t->set_block("product_row", "adminprod", "adminprod_blck");
		$t->set_block("adminprod", "adminprodimage", "adminprodimage_blck");
		$t->set_block("adminprod", "special_flag", "special_flag_blck");
	$t->set_block("product_row", "notadminprod", "notadminprod_blck");
		$t->set_block("notadminprod", "notadminprodimage", "notadminprodimage_blck");
	$t->set_block("product_row", "brand_used", "brand_used_blck");
	$t->set_block("product_row", "iva_used", "iva_used_blck");
	$t->set_block("product_row", "discount_block", "discount_block_blck");
		$t->set_block("discount_block", "discqty_block", "discqty_block_blck");
	$t->set_block("product_row", "weight_used", "weight_used_blck");
// ... end of the blocks :)
$t->set_var("product_rows", "");	// Now let us reset the product rows container...
for ($i=$first; $i<=$last; $i++) {
// Now let us reset the blocks contents...
// We indent the code to highlight the blocks' hierarchical nesting...
	$t->set_var("adminprod_blck", "");
		$t->set_var("adminprodimage_blck", "");
		$t->set_var("special_flag_blck", "");
	$t->set_var("notadminprod_blck", "");
		$t->set_var("notadminprodimage_blck", "");
	$t->set_var("brand_used_blck", "");
	$t->set_var("iva_used_blck", "");
	$t->set_var("discount_block_blck", "");
		$t->set_var("discqty_block_blck", "");
	$t->set_var("weight_used_blck", "");
// ... now we have reset all nested blocks :)
	$t->set_var(array(
		"product_id"	=> $SESSION["searchres"][$i]["id"],
		"pname"		=> ov($SESSION["searchres"][$i]["name"]),
		"price"		=> $SESSION["searchres"][$i]["price"],
		"fprice"	=> formatted_price($SESSION["searchres"][$i]["price"]),
		"description"	=> ovwbr($SESSION["searchres"][$i]["description"])
	));
	if (has_priv("admin")) {
		if (file_exists($CFG->productsdir.string_cleanup($SESSION["searchres"][$i]["id"]).".thumb.jpg")) {
			$t->set_var(array(
				"imagefilename"	=> string_cleanup($SESSION["searchres"][$i]["id"]),
				"thumbwidth"	=> $SESSION["searchres"][$i]["thumbwidth"],
				"thumbheight"	=> $SESSION["searchres"][$i]["thumbheight"]
			));
			$t->parse("adminprodimage_blck", "adminprodimage", true);
		}
		$t->set_var("p_special_level", $SESSION["searchres"][$i]["special_level"]);
		if ($SESSION["searchres"][$i]["special_flag"])
			$t->parse("special_flag_blck", "special_flag", true);
		$t->parse("adminprod_blck", "adminprod", true);
	} else {
		if (file_exists($CFG->productsdir.string_cleanup($SESSION["searchres"][$i]["id"]).".thumb.jpg")) {
			$t->set_var(array(
				"imagefilename"	=> string_cleanup($SESSION["searchres"][$i]["id"]),
				"thumbwidth"	=> $SESSION["searchres"][$i]["thumbwidth"],
				"thumbheight"	=> $SESSION["searchres"][$i]["thumbheight"]
			));
			$t->parse("notadminprodimage_blck", "notadminprodimage", true);
		}
		$t->parse("notadminprod_blck", "notadminprod", true);
	}
	if ($SESSION["brand_used"] && $SESSION["searchres"][$i]["bname"] != "") {
		$t->set_var("bname", ov($SESSION["searchres"][$i]["bname"]));
		$t->parse("brand_used_blck", "brand_used", true);
	}
	if ($SESSION["iva_used"]) {
		$t->set_var("iva", $SESSION["searchres"][$i]["iva"]);
		$t->parse("iva_used_blck", "iva_used", true);
	}
	if ($SESSION["searchres"][$i]["discount"] > 0) {
		$t->set_var("discount", $SESSION["searchres"][$i]["discount"]);
		if ($SESSION["searchres"][$i]["discqty"] > 1) {
			$t->set_var("discqty", $SESSION["searchres"][$i]["discqty"]);
			$t->parse("discqty_block_blck", "discqty_block", true);
		}
		$t->parse("discount_block_blck", "discount_block", true);
	}
	if ($SESSION["weight_used"]) {
		$t->set_var(array(
			"weight"	=> $SESSION["searchres"][$i]["weight"],
			"fweight"	=> formatted_weight($SESSION["searchres"][$i]["weight"])
		));
		$t->parse("weight_used_blck", "weight_used", true);
	}
	$t->parse("product_rows", "product_row", true);
}
$t->parse("products_blck", "products", true);

$t->pparse("out", "page");
//include("templates/search_results.ihtml");

?>
